var addActionCheckBoxesToTable = (function()
{
	/**
	 * addCheckBoxActionsToTable
	 * ajoute les cases  cocher des actions dans un tableau
	 * @param id string Identifiant du tableau
	 * @param idActions string Identifiant du champs hidden contenant les donnes des actions  ajouter
	 */
	function addCheckBoxActionsToTable(idTable, idActions)
	{
		var table = document.getElementById(idTable);
		var actions = document.getElementById(idActions);
		
		addCheckBoxActionsToGroup(table, "thead", actions);
		addCheckBoxActionsToGroup(table, "tfoot", actions);
	}
	
	/**
	 * addCheckBoxActionsToTable
	 * ajoute les cases  cocher des actions dans l'entte ou le pied du tableau
	 * @param table object Element reprsentant le tableau
	 * @param group string Nom du groupe de cellule du tableau ("thead" ou "tfoot")
	 * @param actions object Element input contenant les donnes sur les actions
	 */
	function addCheckBoxActionsToGroup(table, group, actions)
	{
		var tgroup = table.getElementsByTagName(group).item(0);
		var tr = tgroup.getElementsByTagName("tr").item(0);
		var th = tr.getElementsByTagName("th");

		// Ajout de l'attribut rowspan aux cellules du groupe
		for (var i = 0; i < (th.length - 1); i ++) {
			th[i].rowSpan = "2";
		}
	
		// Cration d'une nouvelle ligne de tableau
		var newTr = document.createElement("tr");
		newTr.className = tr.className;
	
		switch(group) {
			case "thead" :
				// Cration de la cellule contenant les cases  cocher
				var td = createTdAction(table, "head", actions);
				
				newTr.appendChild(td);
				tgroup.appendChild(newTr);
				break;
				
			case "tfoot" :
				// Clonage de la dernire cellule de la ligne du groupe
				var tdCloned = th[th.length - 1].cloneNode(true);		
				// Cration de la cellule contenant les cases  cocher
				var td = createTdAction(table, "foot", actions);
				// Remplacement de la dernire cellule de la ligne du groupe
				tr.replaceChild(td, th[th.length - 1]);
	
				newTr.appendChild(tdCloned);
				tgroup.appendChild(newTr);
				break;
				
			default :	
				return false;
		}
	}
	
	/**
	 * createTdAction
	 * ajoute les cases  cocher des actions dans l'entte ou le pied du tableau
	 * @param table object Element reprsentant le tableau
	 * @param id string Identifiant des cases  cocher dans la cellule
	 * @param inputActions object Element input contenant les donnes sur les actions  mettre dans la cellule
	 */
	function createTdAction(table, id, inputActions)
	{
		var td = document.createElement('th');
		td.className = "action";
		td.noWrap = "nowrap";
		
		// Ajout des cases  cocher des actions
		var actions = getDataActions(inputActions);
		for (var i in actions) {
			addCheckboxAction(table, td, actions[i]['status'], actions[i]['id'] + "_" + id, actions[i]['title'], actions[i]['img']);
			if (i < (actions.length - 1)) {
				addSpace(td, 3);
			}
		}
	
		return td;	
	}


	/**
	 * getDataActions
	 * rcupre les donnes srialises et les renvoient dsrialises
	 * @param inputActions object Element input contenant les donnes sur les actions  mettre dans la cellule
	 * @return object Element contenant les donnes sur les actions  mettre dans la cellule
	 */
	function getDataActions(inputActions)
	{
		return phpSerializer.unserialize(inputActions.value);
/*
		var a = {
			'status' : 'a',
			'id' : 'actItemsDB',
			'img': 'http://localhost/Admredacteurs_v5.6.0_guppy47a2_2/plugins/adm_redacteurs/inc/img/files/on.gif',
			'title' : 'Activer tous les items dsactivs'
		}	
		var i= {
			'status' : 'i',
			'id' : 'inactItemsDB',
			'img': 'http://localhost/Admredacteurs_v5.6.0_guppy47a2_2/plugins/adm_redacteurs/inc/img/files/off.gif',
			'title' : 'Dsactiver tous les items dsactivs'
		}	
		var d= {
			'status' : 'd',
			'id' : 'delItemsDB',
			'img': 'http://localhost/Admredacteurs_v5.6.0_guppy47a2_2/plugins/adm_redacteurs/inc/img/files/del.gif',
			'title' : 'Supprimer tous les items dsactivs'
		}	
		
		var actions = new Array(a, i, d);	
		
		return actions;
*/	}
	
	
	/**
	 * addCheckboxAction
	 * Ajoute une case  cocher
	 * @param table object Tableau contenant la case  cocher
	 * @param td object Cellule du tableau contenant la case  cocher
	 * @param action string Action de la case  cocher (vnement onclick)
	 * @param id string Identifiant de la case  cocher
	 * @param title string Titre de la case  cocher
	 * @param imgPath string Chemin de l'image associe  la case  cocher
	 * @return false
	 */
	function addCheckboxAction(table, td, action, id, title, imgPath)
	{
		var checkbox = createCheckbox(id, title);
		var img = createImg(imgPath, title);
		var label = createLabel(id, img);
		
		checkbox.onclick = function () {
			checkAllCheckboxByStatus(table, checkbox, action);
		};
		
		td.appendChild(checkbox);
		td.appendChild(label);
	}
	
	/**
	 * checkAllCheckboxByStatus
	 * coche toutes cases selon leur status
	 * @param table object Tableau contenant les cases  cocher
	 * @param checkbox object Case  cocher responsable de l'action
	 * @param action string Status des cases qui doivent tre coches
	 * @return false
	 */
	function checkAllCheckboxByStatus(table, checkbox, action)
	{
		var items = table.getElementsByTagName('input');
	
		for (var i = 0; i < items.length; i ++) {
			var itemStatus = items.item(i).id.substring(0, 1);
			if (itemStatus == action) {
				items.item(i).checked = (checkbox.checked)? true : false;
                
//                var img = items.item(i).nextSibling.firstChild;
//                toggleImageStatus(img);
			}
		}
	}

/*
    function toggleImageStatus(img)
    {
        var path = img.src.split('/');
        var image = path[path.length - 1];
  
		path[path.length - 1] = (image == "on.gif") ? "off.gif" : "on.gif";
        
        img.src = path.join('/'); 
    }
*/    	
	/**
	 * createCheckbox
	 * cre une case  cocher <input type="checkbox" />
	 * @param id string id de la case  cocher
	 * @return object case  cocher
	 */
	function createCheckbox(id, title)
	{
		var checkbox = document.createElement('input');
		checkbox.type = 'checkbox';
		checkbox.id = id;
		checkbox.name = id;
		checkbox.title = title;
			
		return checkbox;
	}
	
	/**
	 * createLabel
	 * cre un libell <label>
	 * @param id string id de la balise <label>
	 * @param contents string contenu de la balise <label>
	 * @return object label
	 */
	function createLabel(id, contents)
	{
		var label = document.createElement('label');
		label.htmlFor = id;
		label.appendChild(contents);
		
		return label;
	}
	
	/**
	 * createImg
	 * cre une image <img />
	 * @param path string Chemin de l'image
	 * @param alt string Texte alternatif de l'image
	 * @return object image
	 */
	function createImg(path, alt)
	{
		var img = document.createElement('img');
		img.src = path;
		img.alt = alt;
		img.title = alt;
		
		return img;
	}
	
	/**
	 * addSpace
	 * ajoute un ou des espaces inscables
	 * @param parent object Element parent contenant les espaces
	 * @param nbSpace integer Nombre d'espaces
	 */
	function addSpace(parent, nbSpace)
	{
		var space = document.createTextNode(createSpace(nbSpace));
		parent.appendChild(space);
	}
	
	/**
	 * createSpace
	 * cre un ou des espaces inscables
	 * @param nb integer nombre d'espace inscable
	 * @return string espace inscable
	 */
	function createSpace(nb)
	{
		var space = '';
		for (var i = 0; i < nb; i ++) {
			space += String.fromCharCode(160);
		}
	
		return space;
	}

	/**
	 * Membres publics
	 */
	return {
		/**
		 * init
		 * Initialisation de la fonction
		 * @param string id Identifiant du champ input  remplacer par le menu
		 * @param string idListCat Identifiant du champ input hidden contenant la liste des catgories 
		 */
		"init" : function (idTable, idActions)
				 {
                    if (document.getElementById(idTable) && document.getElementById(idActions)) {
            			addCheckBoxActionsToTable(idTable, idActions);
					} else {
						return false;
					}
				 }
	};
	
}) ();